@@ -4,8 +4,11 @@
 
 contains QWebEngineView-based classes
 """
+
+import logging
+
 try:
     from .webengineview import WebEngineView
     __all__ = ["WebEngineView"]
 except ModuleNotFoundError:
-    pass
+    logging.warning("Tried to import WebEngineView but not installed.")
