@@ -8,8 +8,12 @@ from qtpy import QtCore, QtWidgets
 from prettyqt import core, widgets
 from prettyqt.utils import bidict
 
-MODES = bidict(maximum=QtWidgets.QLayout.SetMaximumSize,
-               fixed=QtWidgets.QLayout.SetFixedSize)
+MODES = bidict(default=QtWidgets.QLayout.SetDefaultConstraint,
+               fixed=QtWidgets.QLayout.SetFixedSize,
+               minimum=QtWidgets.QLayout.SetMinimumSize,
+               maximum=QtWidgets.QLayout.SetMaximumSize,
+               min_and_max=QtWidgets.QLayout.SetMinAndMaxSize,
+               none=QtWidgets.QLayout.SetNoConstraint)
 
 ALIGNMENTS = bidict(left=QtCore.Qt.AlignLeft,
                     right=QtCore.Qt.AlignRight,
@@ -35,6 +39,15 @@ class Layout(QtWidgets.QLayout):
     def __repr__(self):
         return f"{self.__class__.__name__}: {len(self)} children"
 
+    def __iter__(self):
+        return iter(self[i] for i in range(self.count()))
+
+    def __contains__(self, item):
+        return item in self.get_children()
+
+    def get_children(self):
+        return list(self)
+
     def set_margin(self, margin: int):
         self.setContentsMargins(margin, margin, margin, margin)
 
@@ -44,7 +57,7 @@ class Layout(QtWidgets.QLayout):
     def set_size_mode(self, mode: str):
         """set the size mode of the layout
 
-        Allowed values are "maximum", "fixed"
+        Allowed values are "default", "fixed", "minimum", "maximum", "min_and_max", "none"
 
         Args:
             mode: size mode for the layout
@@ -59,7 +72,7 @@ class Layout(QtWidgets.QLayout):
     def get_size_mode(self) -> str:
         """returns current size mode
 
-        Possible values: "maximum", "fixed"
+        Possible values: "default", "fixed", "minimum", "maximum", "min_and_max", "none"
 
         Returns:
             size mode
