@@ -6,7 +6,7 @@
 from qtpy import QtWidgets, QtCore
 
 from prettyqt import widgets
-from prettyqt.utils import bidict
+from prettyqt.utils import bidict, icons
 
 
 ICONS = bidict(none=QtWidgets.QMessageBox.NoIcon,
@@ -60,12 +60,12 @@ class MessageBox(QtWidgets.QMessageBox):
                 self.add_button(b)
 
     @classmethod
-    def message(cls, text, title=None, icon=None):
+    def message(cls, text: str, title: str = None, icon: icons.IconType = None):
         m = cls(cls.NoIcon, title, text)
         m.set_icon(icon)
         return m.show_blocking()
 
-    def set_icon(self, icon):
+    def set_icon(self, icon: icons.IconType):
         if icon in ICONS:
             self.setIcon(ICONS[icon])
             return None
@@ -77,7 +77,7 @@ class MessageBox(QtWidgets.QMessageBox):
     def get_standard_buttons(self) -> list:
         return [k for k, v in BUTTONS.items() if v & self.standardButtons()]
 
-    def add_button(self, button: str):
+    def add_button(self, button: str) -> QtWidgets.QPushButton:
         """add a default button
 
         Valid arguments: "none", "cancel", "ok", "save", "open", "close",
@@ -110,7 +110,7 @@ class MessageBox(QtWidgets.QMessageBox):
         Allowed values are "rich", "plain", "auto"
 
         Args:
-            mode: text format to use
+            text_format: text format to use
 
         Raises:
             ValueError: text format does not exist
