@@ -7,14 +7,12 @@ from qtpy import QtWidgets
 
 from prettyqt import widgets
 
-
 QtWidgets.QWidgetAction.__bases__ = (widgets.Action,)
 
 
 class WidgetAction(QtWidgets.QWidgetAction):
-    pass
-    # def __init__(self, text="", icon=None, parent=None, shortcut="", tooltip=""):
-    #     super().__init__(parent=parent)
+    def __init__(self, parent=None):
+        super().__init__(parent)
     #     self.set_text(text)
     #     self.set_icon(icon)
     #     self.set_shortcut(shortcut)
