@@ -46,6 +46,12 @@ def test_buffer():
         pass
 
 
+def test_coreapplication(qapp):
+    def test():
+        pass
+    core.CoreApplication.call_on_exit(test)
+
+
 def test_date():
     date = core.Date(1, 1, 2000)
     with open("data.pkl", "wb") as jar:
@@ -166,7 +172,7 @@ def test_runnable():
     core.Runnable()
 
 
-def test_settings():
+def test_settings(qapp):
     settings = core.Settings("1", "2")
     settings.clear()
     settings.set_value("test", "value")
